<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                xmlns:msxsl="urn:schemas-microsoft-com:xslt" 
						 xmlns:compartment="http://wwwmgs.bionet.nsc.ru/compartmentnamespace"
						 xmlns:protein="http://wwwmgs.bionet.nsc.ru/proteinnamespace"
						 xmlns:gene="http://wwwmgs.bionet.nsc.ru/genenamespace"
						 xmlns:reaction="http://wwwmgs.bionet.nsc.ru/reactionnamespace"
						 version="1.0">

	<msxsl:script language="JScript" implements-prefix="protein">
		<!-- определение подписи для протеина в зависимости от os и sn или nm протеина -->
		function NM(nodelist) 
			{
			node = nodelist.nextNode();
			os = node.selectSingleNode("os/latin");
			if (os)
				{
				ost = os.text;
				
				// отбрасывается общепринятое название организма (в скобках)
				n = ost.indexOf("(");
				if (n != -1)
					ost = ost.substr(0, n);

				// разбить на куски по пробелу
				ss = ost.split(" ");
				ost = "";
				for (i = 0; i &lt; ss.length; i++)
					ost += ss[i].charAt(0);
											
				return ost;
				}
	
	   	return "[undefined]";
	    	}
	
	</msxsl:script>

	<msxsl:script language="JScript" implements-prefix="gene">
		<!-- определение подписи для протеина в зависимости от os и sn или nm протеина -->
		function NM(nodelist) 
			{
			node = nodelist.nextNode();
			os = node.selectSingleNode("os/latin");
			if (os)
				{
				ost = os.text;
				
				// отбрасывается общепринятое название организма (в скобках)
				n = ost.indexOf("(");
				if (n != -1)
					ost = ost.substr(0, n);

				// разбить на куски по пробелу
				ss = ost.split(" ");
				ost = "";
				for (i = 0; i &lt; ss.length; i++)
					ost += ss[i].charAt(0);
											
				return ost;
				}
	
	   	return "[undefined]";
	    	}
	
	</msxsl:script>

	<!-- для схемы правило отличается радикально -->
	<xsl:template match="/diagram">
		<node>
			<xsl:attribute name="name"><xsl:value-of select="/diagram/name"/>::<xsl:value-of select="/diagram/ac"/></xsl:attribute>
			<xsl:attribute name="type"><xsl:value-of select="@type"/></xsl:attribute>
		</node>
		
	</xsl:template>

	<xsl:template match="/object">
		<node>
			<xsl:attribute name="name">
				<xsl:choose>
					<!-- для компартмента просто берется значение атрибута "ac" -->
					<xsl:when test="@type[.='1']"><xsl:value-of select="/object/ac"/></xsl:when>

					<!-- для процесса просто берется "nm" -->
					<xsl:when test="@type[.='2']"><xsl:value-of select="/object/nm"/></xsl:when>

					<!-- для протеина берется короткая форма атрибута "os" и к нему добавляется "sn" (если есть) и "nm" и все синонимы -->
					<xsl:when test="@type[.='3']">
						<xsl:if test="/object/os"><xsl:value-of select="protein:NM(.)"/> : 
</xsl:if>
						<xsl:if test="/object/sn"><xsl:value-of select="/object/sn"/></xsl:if>
						<xsl:if test="/object/nm"> : <xsl:value-of select="/object/nm"/></xsl:if>
						<xsl:for-each select="/object/sy"> : <xsl:value-of select="."/></xsl:for-each>
					</xsl:when>

					<!-- для реакции просто берется "nm" -->
					<xsl:when test="@type[.='4']">
						<xsl:choose>
	                                        	<xsl:when test="/object/nm">
								<xsl:value-of select="/object/nm"/>
							</xsl:when>
	                                                <xsl:otherwise>[undefined]</xsl:otherwise>
                                                </xsl:choose>
					</xsl:when>

					<!-- для гена просто берется "nm" -->
					<xsl:when test="@type[.='5']">
						<xsl:if test="/object/os"><xsl:value-of select="gene:NM(.)"/>
 : 
</xsl:if>
						<xsl:if test="/object/sn"><xsl:value-of select="/object/sn"/></xsl:if>
						<xsl:if test="/object/nm"> : <xsl:value-of select="/object/nm"/></xsl:if>
					</xsl:when>

					<!-- для RNA просто берется "nm" -->
					<xsl:when test="@type[.='6']">
						<xsl:if test="/object/os"><xsl:value-of select="protein:NM(.)"/>
 : 
</xsl:if>
						<xsl:if test="/object/sn"><xsl:value-of select="/object/sn"/></xsl:if>
						<xsl:if test="/object/nm"> : <xsl:value-of select="/object/nm"/></xsl:if>
					</xsl:when>

					<!-- для субстанции просто берется "nm" -->
					<xsl:when test="@type[.='7']"><xsl:value-of select="/object/nm"/></xsl:when>
					
					<!-- для пользователя берется его полное имя -->
					<xsl:when test="@type[.='-1']"><xsl:value-of select="/object/name"/></xsl:when>
					<xsl:when test="@type[.='8']"><xsl:value-of select="/object/name"/></xsl:when>
					<xsl:when test="@type[.='9']">
						<xsl:if test="/object/os"><xsl:value-of select="gene:NM(.)"/>
 : 
</xsl:if>
						<xsl:if test="/object/sn"><xsl:value-of select="/object/sn"/></xsl:if>
						<xsl:if test="/object/nm"> : <xsl:value-of select="/object/nm"/></xsl:if>
					</xsl:when>
					<xsl:when test="@type[.='11']"><xsl:value-of select="/object/sn"/>::<xsl:value-of select="/object/latin"/>(<xsl:value-of select="/object/english"/>)</xsl:when>
					<xsl:when test="@type[.='10']">
				      		<xsl:if test="/object/authors">
					             <xsl:choose>
					                 <xsl:when test="string-length(normalize-space(substring-before(/object/authors,','))) != 0">
					                     <xsl:value-of select="normalize-space(substring-before(/object/authors,','))"/>
					                 </xsl:when>
					                 <xsl:when test="string-length(normalize-space(substring-before(/object/authors,'and'))) != 0">
					                     <xsl:value-of select="normalize-space(substring-before(/object/authors,'and'))"/>
					                 </xsl:when>
					                 <xsl:otherwise>
					                     <xsl:value-of select="normalize-space(/object/authors)"/>
					                 </xsl:otherwise>
					             </xsl:choose>
					    </xsl:if>
				         <xsl:if test="/object/year"> :<xsl:value-of select="/object/year"/></xsl:if>
				         <xsl:if test="/object/pages/first"> :<xsl:value-of select="/object/pages/first"/></xsl:if>
					  <xsl:if test="/object/journal"> :<xsl:value-of select="/object/journal"/></xsl:if>
				</xsl:when>
				<xsl:when test="@type[.='12']">
					<xsl:if test="/object/name"><xsl:value-of select="/object/name"/></xsl:if><xsl:for-each select="/object/sy"> : <xsl:value-of select="normalize-space(.)"/></xsl:for-each>
				</xsl:when>
				<xsl:when test="@type[.='13']">
					<xsl:if test="/object/nm"><xsl:value-of select="/object/nm"/></xsl:if>
				</xsl:when>
				<xsl:when test="@type[.='14']">
						<xsl:if test="/object/os"><xsl:value-of select="gene:NM(.)"/>
 : 
</xsl:if>
						<xsl:if test="/object/sn"><xsl:value-of select="/object/sn"/></xsl:if>
						<xsl:if test="/object/nm"> : <xsl:value-of select="/object/nm"/></xsl:if>
					</xsl:when>


				</xsl:choose>
			</xsl:attribute>
			<xsl:attribute name="type"><xsl:value-of select="@type"/></xsl:attribute>
		</node>
		
	</xsl:template>
						
</xsl:stylesheet>
