<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                	xmlns:msxsl="urn:schemas-microsoft-com:xslt" 
	 		xmlns:reaction="http://wwwmgs.bionet.nsc.ru/reactionnamespace"
						version="1.0">
     <msxsl:script language="JScript" implements-prefix="reaction"><![CDATA[
         function checkOs(node)
         {             
             var nl1 = node.selectNodes("/reaction/input/input_item/object/os");
             var nl2 = node.selectNodes("/reaction/output/output_item/object/os");
             
             var out  = new Array();
             
             for(i=0; i  < nl1.length; i++)
                {
                        var os = nl1.item(i);
                        var osID = os.getAttribute("id");
                        
                        var found = "false";
                        for(j=0;j<out.length;j++)
                        {
                        	if(out[j] == osID)
                        	{
                        		found= "true";
                        	}
                        }
                        
                        if(found == "false")
                        {
                        	out[out.length] = osID;
                        }
                }

             for(i=0; i  < nl2.length; i++)
                {
                        var os = nl2.item(i);
                        var osID = os.getAttribute("id");
                        
                        var found = "false";
                        for(j=0;j<out.length;j++)
                        {
                        	if(out[j] == osID)
                        	{
                        		found= "true";
                        	}
                        }
                        
                        if(found == "false")
                        {
                        	out[out.length] = osID;
                        }
                }
                
                return out;
         }
         
         function isValid(nodelist)
         {
         	var node = nodelist.nextNode();

         	var array = checkOs(node);
             if(array.length > 1)
                return "false";
                
             return "true";
         }
         
         function getMessage(nodelist)
         {
         	var node = nodelist.nextNode();

         	var array = checkOs(node);
             
             
             var message = "Error: There are different species in reaction (";
             for(j=0;j<array.length;j++)
             {
             		var Latin = node.selectSingleNode("//os[@id='"+array[j]+"']/Latin");
             		
             		if(j>0)message+=",";
             		
             		message+=Latin.text;
             }         	
             
            message+=")";
            
             return message ;
         }
]]></msxsl:script>

	<xsl:template match="/reaction">
		<reaction>
			<xsl:apply-templates select="object"/>

		<xsl:if test="reaction:isValid(.) = 'false'">
			<input_output invalid="true"><xsl:attribute name="message"><xsl:value-of select="reaction:getMessage(.)"/></xsl:attribute>
			</input_output>
		</xsl:if>

			
		</reaction>
	</xsl:template>

	<xsl:template match="object">

	    <xsl:for-each select="local_comment_item">
        	<local_comment_item>
	    	    <xsl:attribute name="invalid">
	        	<xsl:choose>
	            	    <xsl:when test="boolean(ref)">
	            		<xsl:value-of select="boolean(boolean(string-length(CC/text()) = 0) or not(boolean(ref/@id)))"/>
		    	    </xsl:when>
			    <xsl:otherwise>
				<xsl:value-of select="boolean(string-length(CC/text()) = 0)"/>
			    </xsl:otherwise>
			</xsl:choose>
	    	    </xsl:attribute>
		</local_comment_item>
	    </xsl:for-each>

	<xsl:for-each select="const">
	    <const>
		<xsl:attribute name="invalid">
		    <xsl:value-of select="boolean(string-length(name/text()) = 0) or boolean(string-length(value/text()) = 0)"/>
		</xsl:attribute>		
	    </const>
	</xsl:for-each>
	
	<xsl:choose>
	    <xsl:when test="nm/text()='regulatory event'">
		<xsl:if test="type">
		    <type invalid="true"/>
		</xsl:if>
	    </xsl:when>
	    <xsl:when test="nm/text()='reaction'">
		<type>
		    <xsl:attribute name="invalid">
			<xsl:value-of select="boolean(string-length(type/text()) = 0)"/>
		    </xsl:attribute>
		</type>		
	    </xsl:when>
	</xsl:choose>

        <xsl:for-each select="cell">
            <cell>
                <xsl:attribute name="invalid">
                    <xsl:value-of select="boolean(not(boolean(@id)))"/>
                </xsl:attribute>
            </cell>
        </xsl:for-each>
											    
											    

	<nm>
	    <xsl:attribute name="invalid">
		<xsl:value-of select="boolean(string-length(nm/text()) = 0)"/>
	    </xsl:attribute>
	</nm>

	<xsl:if test="nm/text()='regulatory event'">
	    <at>
		<xsl:attribute name="invalid">
		    <xsl:value-of select="boolean(string-length(at/text()) = 0)"/>
		</xsl:attribute>
	    </at>
	</xsl:if>

	<xsl:if test="nm/text()='reaction'">
	    <at>
		<xsl:attribute name="invalid">
		    <xsl:value-of select="boolean(at)"/>
		</xsl:attribute>
	    </at>
	</xsl:if>



	<ef>
	    <xsl:attribute name="invalid">
		<xsl:value-of select="boolean(string-length(ef/text()) = 0)"/>
	    </xsl:attribute>
	</ef>

	<xsl:for-each select="keggreaction">
	    <keggreaction>
		<xsl:attribute name="invalid">
	               <xsl:value-of select="boolean(not(starts-with(./text(),'R')) or string-length(./text()) != 6) or number(substring(./text(),2)) != number(substring(./text(),2))"/>
	        </xsl:attribute>
	    </keggreaction>
	</xsl:for-each>
	

	<xsl:for-each select="total_comment_item">
            <total_comment_item>
	        <xsl:attribute name="invalid">
	            <xsl:choose>
	                <xsl:when test="boolean(ref)">
	            	    <xsl:value-of select="boolean(boolean(string-length(cc/text()) = 0) or not(boolean(ref/@id)))"/>
		        </xsl:when>
			<xsl:otherwise>
			    <xsl:value-of select="boolean(string-length(cc/text()) = 0)"/>
			</xsl:otherwise>
		    </xsl:choose>
	        </xsl:attribute>
	    </total_comment_item>
	</xsl:for-each>
	
	<xsl:for-each select="method">
			<method>
					<xsl:attribute name="invalid"><xsl:value-of select="boolean(string-length(./text())= 0) or (count(../method[text()=current()/text()])>1)"/></xsl:attribute>
			</method>
	</xsl:for-each>
	
	<xsl:for-each select="up">
			<up>
					<xsl:attribute name="invalid"><xsl:value-of select="boolean(string-length(./text())= 0) or (count(../up[text()=current()/text()])>1)"/></xsl:attribute>
			</up>
	</xsl:for-each>

	<xsl:choose>
		<xsl:when test="boolean(evidence='bioinformatical')">
			<method ><xsl:attribute name="invalid"><xsl:value-of select="not(boolean(method)) "/></xsl:attribute></method>
		</xsl:when>
		<xsl:when test="boolean(up)">
		</xsl:when>	
		
	     <xsl:when test="boolean(ref)">
	        <xsl:for-each select="ref">
	            <ref>
	                <xsl:attribute name="invalid">
	                    <xsl:value-of select="not(boolean(@id))"/>
	                </xsl:attribute>
	            </ref>
	        </xsl:for-each>
	    </xsl:when>
	    <xsl:otherwise><ref invalid="true"/></xsl:otherwise>
	</xsl:choose>	
	
	</xsl:template>
</xsl:stylesheet>
