<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>

	<xsl:template match="/">
		<xsl:apply-templates select="diagram"/>
	</xsl:template>

	<xsl:template match="diagram">
		<xsl:copy>
			<xsl:attribute name="name"><xsl:value-of select="name"/></xsl:attribute>
			<xsl:attribute name="x"><xsl:value-of select="x"/></xsl:attribute>
			<xsl:attribute name="y"><xsl:value-of select="y"/></xsl:attribute>
			<xsl:attribute name="width"><xsl:value-of select="width"/></xsl:attribute>
			<xsl:attribute name="height"><xsl:value-of select="height"/></xsl:attribute>
			
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:template>

	<!--выбираем из схемы все объекты -->
	<xsl:template match="objects">
			<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="compartment">
	<xsl:variable name="id_comp"><xsl:value-of select="./@id"/></xsl:variable>
	<xsl:variable name="comp_ac"><xsl:value-of select="./object/ac"/></xsl:variable>
	<xsl:for-each select="//link">
		<xsl:if test="$id_comp = ./@target">
		<xsl:element name="object">
 			<xsl:attribute name="x"><xsl:value-of select="x"/></xsl:attribute>
			<xsl:attribute name="y"><xsl:value-of select="y"/></xsl:attribute>
			<xsl:attribute name="width"><xsl:value-of select="width"/></xsl:attribute>
			<xsl:attribute name="height"><xsl:value-of select="height"/></xsl:attribute>
			<xsl:attribute name="type">compartment</xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="$id_comp"/></xsl:attribute>
		<xsl:attribute name="name"><xsl:value-of select="$comp_ac"/></xsl:attribute>
		</xsl:element>
		</xsl:if>
	</xsl:for-each>
		<xsl:apply-templates/>
	</xsl:template>


	<xsl:template match="protein">
		<xsl:element name="object">
			<xsl:attribute name="type">protein</xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="./object/sn"/></xsl:attribute>
			<xsl:attribute name="x"><xsl:value-of select="x"/></xsl:attribute>
			<xsl:attribute name="y"><xsl:value-of select="y"/></xsl:attribute>

		</xsl:element>
	</xsl:template>

	<xsl:template match="gene">
		<xsl:element name="object">
			<xsl:attribute name="type">gene</xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="./object/sn"/></xsl:attribute>
			<xsl:attribute name="x"><xsl:value-of select="x"/></xsl:attribute>
			<xsl:attribute name="y"><xsl:value-of select="y"/></xsl:attribute>

		</xsl:element>
	</xsl:template>


	<xsl:template match="process">
		<xsl:element name="object">
			<xsl:attribute name="type">process</xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="./object/sn"/></xsl:attribute>
			<xsl:attribute name="x"><xsl:value-of select="x"/></xsl:attribute>
			<xsl:attribute name="y"><xsl:value-of select="y"/></xsl:attribute>

		</xsl:element>
	</xsl:template>


	<xsl:template match="rna">
		<xsl:element name="object">
			<xsl:attribute name="type">rna</xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="./object/sn"/></xsl:attribute>
			<xsl:attribute name="x"><xsl:value-of select="x"/></xsl:attribute>
			<xsl:attribute name="y"><xsl:value-of select="y"/></xsl:attribute>

		</xsl:element>
	</xsl:template>


	<xsl:template match="substance">
		<xsl:element name="object">
			<xsl:attribute name="type">substance</xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="./object/sn"/></xsl:attribute>
			<xsl:attribute name="x"><xsl:value-of select="x"/></xsl:attribute>
			<xsl:attribute name="y"><xsl:value-of select="y"/></xsl:attribute>

		</xsl:element>
	</xsl:template>


	<xsl:template match="operon">
		<xsl:element name="object">
			<xsl:attribute name="type">operon</xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="./object/sn"/></xsl:attribute>
			<xsl:attribute name="x"><xsl:value-of select="x"/></xsl:attribute>
			<xsl:attribute name="y"><xsl:value-of select="y"/></xsl:attribute>

		</xsl:element>
	</xsl:template>


	<!--  выбираем все реакции -->
	<xsl:template match="reaction">
			<xsl:element name="object">
				<xsl:attribute name="type"><xsl:value-of select="./object/nm"/></xsl:attribute>
				<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
				<xsl:attribute name="x"><xsl:value-of select="x"/></xsl:attribute>
				<xsl:attribute name="y"><xsl:value-of select="y"/></xsl:attribute>

				<xsl:choose>
					<xsl:when test="./object/nm[text()='reaction']">
						<xsl:attribute name="state"><xsl:value-of select="./object/ef"/></xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="state"><xsl:value-of select="./object/at"/></xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
	</xsl:template>
	
	
	
	<xsl:template match="links">
		<xsl:copy>
			<xsl:apply-templates select="link"/>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="link">
		<xsl:copy-of select="."/>
	</xsl:template>
	
	<!-- Отсекаем все узлы на которые нет шаблонов-->

<xsl:template match="*">
</xsl:template>

</xsl:stylesheet>
